# Functions for bmi_mortality2.nw


# For adjusted and unadjusted analyses
analysis_fun_cardio <- function(df_dx, df_pts, evt,simple.outcome,comorbid,gap,imputed,imputed_wo_BMI){
   # Only include men in the analysis
   female.ids <- unique(df_pts$cfar_pid[which(df_pts$gender.factor == 'Female')])
   df_pts <- subset(df_pts, gender.factor == 'Male')
   df_dx <- subset(df_dx, cfar_pid %nin% female.ids)
   
   # If not imputing data, need to remove those subjects with missing baseline bmi
   if(!imputed){
      df_pts <- subset(df_pts, !is.na(baseline_bmi))
      df_dx <- subset(df_dx, cfar_pid %in% df_pts$cfar_pid)
   }
   
   # If censoring at the year or more gap, need to correct age_at_last_activity
   if(gap) {
      df_pts$age_at_last_activity_or_death <- df_pts$age_at_last_activity_or_death_corrected
      df_dx <- subset(df_dx, age_at_dx < age_after_year_gap | is.na(age_after_year_gap))
   }

   if(simple.outcome){
      df_dx <- subset(df_dx, group == evt)
      df_pts$age_at_dx <- df_dx[match(df_pts$cfar_pid,df_dx$cfar_pid,nomatch=NA),'age_at_dx']
      df_pts$event_indicator <- ifelse(df_pts$cfar_pid %in% df_dx$cfar_pid,1,0)
      df_pts$time_end <- ifelse(df_pts$event_indicator == 1,df_pts$age_at_dx, df_pts$age_at_last_activity_or_death)
      df_pts$followup_time <- df_pts$time_end - df_pts$age_at_first_art

   } else {
      df_dx <- subset(df_dx, group %in% evt)
      df_dx$overall_evt <- NA
      overall_evt <- lapply(split(subset(df_dx, select=c(cfar_pid,age_at_dx,group)), df_dx$cfar_pid),FUN=function(y){
                                                         if(all(y[,'group'] %in% c(NA,'DEATH'))){
                                                            first_evt <- 'DEATH'
                                                            age_evt <- y[which(y[,'group'] == 'DEATH'),'age_at_dx']
                                                         } else {
                                                            y <- y[order(y[,'age_at_dx']),]
                                                            first_evt <- y[1,'group']
                                                            age_evt <- y[1,'age_at_dx']
                                                         }
                                                         df <- data.frame('cfar_pid'=y[1,'cfar_pid'],
                                                                          'group'=first_evt,
                                                                          'age_at_dx'=age_evt)
                                                         return(df) })
      overall_evt.df <- do.call('rbind',overall_evt)
      df_pts$age_at_dx <- overall_evt.df[match(df_pts$cfar_pid,overall_evt.df$cfar_pid,nomatch=NA),'age_at_dx']
      df_pts$event_indicator <- ifelse(df_pts$cfar_pid %in% df_dx$cfar_pid,1,0)
      df_pts$time_end <- ifelse(df_pts$event_indicator == 1, df_pts$age_at_dx, df_pts$age_at_last_activity_or_death)
      df_pts$followup_time <- df_pts$time_end - df_pts$age_at_first_art

   }

   if(!imputed){
      df_pts <- subset(df_pts, followup_time > 0)
      df_dx <- subset(df_dx, cfar_pid %in% df_pts$cfar_pid)
   }

   followup_time <- round(quantile(df_pts$followup_time, probs=c(0.50,0.25,0.75)),2)
   followup_time.desc <- paste(followup_time[1],' (',followup_time[2],', ',followup_time[3],')',sep='')
   no.evts <- table(df_pts$event_indicator)[2]

   # On non-missing BMI
   followup_time.nonNA.bmi <- round(quantile(df_pts$followup_time[which(!is.na(df_pts$baseline_bmi))], probs=c(0.50,0.25,0.75)),2)
   followup_time.nonNA.bmi.desc <- paste(followup_time.nonNA.bmi[1],' (',followup_time.nonNA.bmi[2],', ',followup_time.nonNA.bmi[3],')',sep='')

   # Number of events by BMI category
   evts_by_bmi <- table(df_pts$event_indicator,df_pts$baseline_bmi_cat.factor)[2,]
   cnts_by_bmi <- paste(evts_by_bmi,collapse=', ')
   nmes_by_bmi <- paste(names(evts_by_bmi),collapse=', ')

   if(imputed & !imputed_wo_BMI){
      # Imputing data for analysis
      set.seed(1)
      impute.1 <- aregImpute(~ log(followup_time)*event_indicator + baseline_bmi + age_at_first_art + year_of_first_art + dichot_race.factor +
                               baseline_cd4_count + pi_first_art.factor + overall_ade_prior_first_art.factor,data=df_pts,subset=followup_time > 0.0)

   } else if(imputed & imputed_wo_BMI){
      impute.1 <- aregImpute(~ log(followup_time)*event_indicator + age_at_first_art + year_of_first_art + dichot_race.factor + 
                                    baseline_cd4_count + pi_first_art.factor + overall_ade_prior_first_art.factor, data=df_pts, subset=followup_time > 0.0)
   }
   Srv.obj <- Surv(df_pts$followup_time, df_pts$event_indicator)

   ddist <<- datadist(df_pts)
   options(datadist='ddist')

   if(comorbid){
      ## Still need to add in year of ART start when Megan gets it to me...
      predictors <- c('rcs(baseline_bmi,4)','age_at_first_art','dichot_race.factor','sqrt(baseline_cd4_count)')

#       predictors <- c('rcs(baseline_bmi,4)','age_at_first_art','dichot_race.factor','sqrt(baseline_cd4_count)')
      fmla <- as.formula(paste('Srv.obj ~ ',paste(predictors,collapse=' + '),sep=''))

      var_list <- c('baseline_bmi','age_at_first_art','dichot_race.factor','baseline_cd4_count')

#       var_list <- c('baseline_bmi','age_at_first_art','dichot_race.factor','baseline_cd4_count')

      unadj_comparisons <- list(c(25,20),c(35,36),'White',c(300,200))
   } else {
      predictors <- c('rcs(baseline_bmi,4)','age_at_first_art','dichot_race.factor','sqrt(baseline_cd4_count)','year_of_first_art',
                      'pi_first_art.factor','overall_ade_prior_first_art.factor')

      fmla <- as.formula(paste('Srv.obj ~ ',paste(predictors,collapse=' + '),sep=''))

      var_list <- c('baseline_bmi','age_at_first_art','dichot_race.factor',
                    'baseline_cd4_count','year_of_first_art','pi_first_art.factor',
                    'overall_ade_prior_first_art.factor')

      unadj_comparisons <- list(c(25,20),c(35,36),'White',c(200,300),c(2005,2006),'No','No')

   }

   # Unadjusted analysis
   unadj_models <- unadj_evts <- vector(mode='list',length=length(predictors))
   summ_unadj_models <- vector(mode='list',length=length(predictors))
   p_unadj <- vector(mode='list',length=length(predictors))

   for(i in 1:length(predictors)){
      unadj_fmla <- as.formula(paste('Srv.obj ~ ',predictors[i],collapse=''))
      unadj_models[[i]] <- cph(unadj_fmla,data=df_pts)
      unadj_evts[[i]] <- unadj_models[[i]]$stats['Events']
      names(unadj_evts)[[i]] <- var_list[i]
     expr <- quote(summary(unadj_models[[i]], var_list=unadj_comparisons[[i]]))
     names(expr)[names(expr) == "var_list"] <- var_list[i]
     summ_unadj_models[[i]] <- eval(expr)
     names(summ_unadj_models)[i] <- var_list[i]
     tmp <- anova(unadj_models[[i]])
     p_unadj[[i]] <- tmp[which(rownames(tmp) == var_list[i]),'P']
     p_unadj[[i]] <- ifelse(p_unadj[[i]] < 0.001, '< 0.001',
                            ifelse(p_unadj[[i]] >= 0.001 & p_unadj[[i]] < 0.01,format(round(p_unadj[[i]],3),nsmall=3),
                                   format(round(p_unadj[[i]],2),nsmall=2)))
   }



   # Additional unadjusted model summaries for BMI
   # c(25,30)
   unadj_bmi_2 <- summary(unadj_models[[1]],baseline_bmi=c(25,30))
   # c(25,35)
   unadj_bmi_3 <- summary(unadj_models[[1]],baseline_bmi=c(25,35))

   if(imputed & !imputed_wo_BMI){
      # Adjusted analysis
      cph.mod <- fit.mult.impute(fmla, data=df_pts, fitter=cph,xtrans=impute.1,x=TRUE,y=TRUE,surv=TRUE) ## Need to remove subjects who had 0 followup time
   } else if(imputed & imputed_wo_BMI){
      cph.mod <- fit.mult.impute(fmla, data=df_pts, fitter=cph, xtrans=impute.1,x=TRUE,y=TRUE,surv=TRUE)
   } else if(!imputed){
      cph.mod <- cph(fmla,x=TRUE,y=TRUE,surv=TRUE, data=df_pts)
   }

   if(comorbid){
      bmi_summ_1 <- summary(cph.mod, baseline_bmi=c(25,20),age_at_first_art=35,
                                     dichot_race.factor='White',baseline_cd4_count=200)
      bmi_summ_2 <- summary(cph.mod, baseline_bmi=c(25,30),age_at_first_art=35,
                                     dichot_race.factor='White',baseline_cd4_count=200)
      bmi_summ_3 <- summary(cph.mod, baseline_bmi=c(25,35),age_at_first_art=35,
                                     dichot_race.factor='White',baseline_cd4_count=200)
      bmi_summ_age <- summary(cph.mod, baseline_bmi=25,age_at_first_art=c(35,36),
                                       dichot_race.factor='White',baseline_cd4_count=200)
      bmi_summ_cd4 <- summary(cph.mod, baseline_bmi=25,age_at_first_art=35,
                                       dichot_race.factor='White',baseline_cd4_count=c(200,300))
      bmi_summ_art_yr <- summary(cph.mod, baseline_bmi=25,age_at_first_art=35,
                                          dichot_race.factor='White',baseline_cd4_count=200)
      order.rows <- c(which(rownames(bmi_summ_1) == 'baseline_bmi'),
                      which(rownames(bmi_summ_1) == 'age_at_first_art'),
                      which(rownames(bmi_summ_1) == 'dichot_race.factor - Non-white:White'),
                      which(rownames(bmi_summ_1) == 'baseline_cd4_count'))
      order.rows <- order.rows + 1

      anova.p <- anova(cph.mod)
      anova.order <- c(which(rownames(anova.p) == 'baseline_bmi'),
                       which(rownames(anova.p) == 'age_at_first_art'),
                       which(rownames(anova.p) == 'dichot_race.factor'),
                       which(rownames(anova.p) == 'baseline_cd4_count'))
      anova.p <- ifelse(anova.p[,'P'] < 0.001,'< 0.001',
                        ifelse(anova.p[,'P'] >= 0.001 & anova.p[,'P'] < 0.01,format(round(anova.p[,'P'],3),nsmall=3),format(round(anova.p[,'P'],2),nsmall=2)))



      order.rows <- c(which(rownames(bmi_summ_1) == 'baseline_bmi'),
                      which(rownames(bmi_summ_1) == 'age_at_first_art'),
                      which(rownames(bmi_summ_1) == 'dichot_race.factor - Non-white:White'),
                      which(rownames(bmi_summ_1) == 'baseline_cd4_count'))
      order.rows <- order.rows + 1

      anova.p <- anova(cph.mod)
      anova.order <- c(which(rownames(anova.p) == 'baseline_bmi'),
                       which(rownames(anova.p) == 'age_at_first_art'),
                       which(rownames(anova.p) == 'dichot_race.factor'),
                       which(rownames(anova.p) == 'baseline_cd4_count'))
      anova.p <- ifelse(anova.p[,'P'] < 0.001,'< 0.001',
                        ifelse(anova.p[,'P'] >= 0.001 & anova.p[,'P'] < 0.01,format(round(anova.p[,'P'],3),nsmall=3),format(round(anova.p[,'P'],2),nsmall=2)))



      df <- data.frame('Covariate'=c('BMI','~~~~~20','~~~~~25 (ref)','~~~~~30','~~~~~35','',
                                     'Age at first ART (per year)','',
                                     'Non-white race','',
                                     'CD4 at first ART (square root transformed)'),
                       'Unadj HR'=c('',format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'baseline_bmi')]][2,'Effect'],2),nsmall=2),
                                    '1.00',format(round(unadj_bmi_2[2,'Effect'],2),nsmall=2),
                                       format(round(unadj_bmi_3[2,'Effect'],2),nsmall=2),
                                    '',format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'age_at_first_art')]][2,'Effect'],2),nsmall=2),
                                    '',format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'dichot_race.factor')]][2,'Effect'],2),nsmall=2),
                                    '',format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'baseline_cd4_count')]][2,'Effect'],2),nsmall=2)),
                       'Unadj CI'=c('',paste('(',format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'baseline_bmi')]][2,'Lower 0.95'],2),nsmall=2),', ',
                                          format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'baseline_bmi')]][2,'Upper 0.95'],2),nsmall=2),')',sep=''),
                                    '',
                                    paste('(',format(round(unadj_bmi_2[2,'Lower 0.95'],2),nsmall=2),', ',format(round(unadj_bmi_2[2,'Upper 0.95'],2),nsmall=2),')',sep=''),
                                    paste('(',format(round(unadj_bmi_3[2,'Lower 0.95'],2),nsmall=2),', ',format(round(unadj_bmi_3[2,'Upper 0.95'],2),nsmall=2),')',sep=''),
                                    '',paste('(',format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'age_at_first_art')]][2,'Lower 0.95'],2),nsmall=2),', ',
                                                 format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'age_at_first_art')]][2,'Upper 0.95'],2),nsmall=2),')',sep=''),
                                    '',paste('(',format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'dichot_race.factor')]][2,'Lower 0.95'],2),nsmall=2),', ',
                                          format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'dichot_race.factor')]][2,'Upper 0.95'],2),nsmall=2),')',sep=''),
                                    '',paste('(',format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'baseline_cd4_count')]][2,'Lower 0.95'],2),nsmall=2),', ',
                                          format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'baseline_cd4_count')]][2,'Upper 0.95'],2),nsmall=2),')',sep='')),
                       'Unadj p'=c(p_unadj[[1]],rep('',times=5),
                                   p_unadj[[2]],'',
                                   p_unadj[[3]],'',
                                   p_unadj[[4]]),
                       'HR'=c('',format(round(bmi_summ_1[order.rows[1],'Effect'],2),nsmall=2),format(1.00,nsmall=2),format(round(bmi_summ_2[order.rows[1],'Effect'],2),nsmall=2),
                                 format(round(bmi_summ_3[order.rows[1],'Effect'],2),nsmall=2),
                              '',format(round(bmi_summ_age[order.rows[2],'Effect'],2),nsmall=2),'',format(round(bmi_summ_1[order.rows[3],'Effect'],2),nsmall=2),
                              '',format(round(bmi_summ_cd4[order.rows[4],'Effect'],2),nsmall=2)),
                       'CI'=c('',
                              paste('(',format(round(bmi_summ_1[order.rows[1],'Lower 0.95'],2),nsmall=2),', ',format(round(bmi_summ_1[order.rows[1],'Upper 0.95'],2),nsmall=2),')',sep=''),'',
                              paste('(',format(round(bmi_summ_2[order.rows[1],'Lower 0.95'],2),nsmall=2),', ',format(round(bmi_summ_2[order.rows[1],'Upper 0.95'],2),nsmall=2),')',sep=''),
                              paste('(',format(round(bmi_summ_3[order.rows[1],'Lower 0.95'],2),nsmall=2),', ',format(round(bmi_summ_3[order.rows[1],'Upper 0.95'],2),nsmall=2),')',sep=''),'',
                              paste('(',format(round(bmi_summ_age[order.rows[2],'Lower 0.95'],2),nsmall=2),', ',format(round(bmi_summ_age[order.rows[2],'Upper 0.95'],2),nsmall=2),')',sep=''),'',
                              paste('(',format(round(bmi_summ_1[order.rows[3],'Lower 0.95'],2),nsmall=2),', ',format(round(bmi_summ_1[order.rows[3],'Upper 0.95'],2),nsmall=2),')',sep=''),'',
                              paste('(',format(round(bmi_summ_cd4[order.rows[4],'Lower 0.95'],2),nsmall=2),', ',format(round(bmi_summ_cd4[order.rows[4],'Upper 0.95'],2),nsmall=2),')',sep='')),
                       'P'=c(anova.p[anova.order[1]],rep('',times=5),
                             anova.p[anova.order[2]],'',
                             anova.p[anova.order[3]],'',
                             anova.p[anova.order[4]]))

      df <- as.matrix(df)
      colnames(df) <- c('Covariate','HR','95\\% CI','P','HR','95\\% CI','P')


   } else {
      bmi_summ_1 <- summary(cph.mod, baseline_bmi=c(25,20),age_at_first_art=35,
                                     dichot_race.factor='White',
                                     baseline_cd4_count=200,year_of_first_art=2005,pi_first_art.factor='No',
                                     overall_ade_prior_first_art.factor='No')
      bmi_summ_2 <- summary(cph.mod, baseline_bmi=c(25,30),age_at_first_art=35,
                                     dichot_race.factor='White',
                                     baseline_cd4_count=200,year_of_first_art=2005,pi_first_art.factor='No',
                                     overall_ade_prior_first_art.factor='No')
      bmi_summ_3 <- summary(cph.mod, baseline_bmi=c(25,35),age_at_first_art=35,
                                     dichot_race.factor='White',
                                     baseline_cd4_count=200,year_of_first_art=2005,pi_first_art.factor='No',
                                     overall_ade_prior_first_art.factor='No')
      bmi_summ_age <- summary(cph.mod, baseline_bmi=25,age_at_first_art=c(35,36),
                                       dichot_race.factor='White',
                                       baseline_cd4_count=200,year_of_first_art=2005,pi_first_art.factor='No',
                                       overall_ade_prior_first_art.factor = 'No')
      bmi_summ_cd4 <- summary(cph.mod, baseline_bmi=25,age_at_first_art=35,
                                       dichot_race.factor='White',
                                       baseline_cd4_count=c(200,300),year_of_first_art=2005,pi_first_art.factor='No',
                                       overall_ade_prior_first_art.factor='No')
      bmi_summ_art_yr <- summary(cph.mod, baseline_bmi=25,age_at_first_art=35,
                                          dichot_race.factor='White',
                                          baseline_cd4_count=200,year_of_first_art=c(2005,2006),pi_first_art.factor='No',
                                          overall_ade_prior_first_art.factor='No')
      order.rows <- c(which(rownames(bmi_summ_1) == 'baseline_bmi'),
                      which(rownames(bmi_summ_1) == 'age_at_first_art'),
                      which(rownames(bmi_summ_1) == 'dichot_race.factor - Non-white:White'),
                      which(rownames(bmi_summ_1) == 'baseline_cd4_count'),
                      which(rownames(bmi_summ_art_yr) == 'year_of_first_art'),
                      which(rownames(bmi_summ_1) == 'pi_first_art.factor - Yes:No'),
                      which(rownames(bmi_summ_1) == 'overall_ade_prior_first_art.factor - Yes:No'))
      order.rows <- order.rows + 1
   
      anova.p <- anova(cph.mod)
      anova.order <- c(which(rownames(anova.p) == 'baseline_bmi'),
                       which(rownames(anova.p) == 'age_at_first_art'),
                       which(rownames(anova.p) == 'dichot_race.factor'),
                       which(rownames(anova.p) == 'baseline_cd4_count'),
                       which(rownames(anova.p) == 'year_of_first_art'),
                       which(rownames(anova.p) == 'pi_first_art.factor'),
                       which(rownames(anova.p) == 'overall_ade_prior_first_art.factor'))
      anova.p <- ifelse(anova.p[,'P'] < 0.001,'< 0.001',
                        ifelse(anova.p[,'P'] >= 0.001 & anova.p[,'P'] < 0.01,format(round(anova.p[,'P'],3),nsmall=3),format(round(anova.p[,'P'],2),nsmall=2)))

      
      
      
      df <- data.frame('Covariate'=c('BMI','~~~~~20','~~~~~25 (ref)','~~~~~30','~~~~~35','',
                                     'Age at first ART (per year)','',
                                     'Non-white race','',
                                     'CD4 at first ART (square root transformed)','',
                                     'Year of ART initiation (per year)','',
                                     'PI in first ART','','Prior ADE'),
                       'Unadj HR'=c('',format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'baseline_bmi')]][2,'Effect'],2),nsmall=2),
                                    '1.00',format(round(unadj_bmi_2[2,'Effect'],2),nsmall=2),
                                       format(round(unadj_bmi_3[2,'Effect'],2),nsmall=2),
                                    '',format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'age_at_first_art')]][2,'Effect'],2),nsmall=2),
                                    '',format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'dichot_race.factor')]][2,'Effect'],2),nsmall=2),
                                    '',format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'baseline_cd4_count')]][2,'Effect'],2),nsmall=2),
                                    '',format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'year_of_first_art')]][2,'Effect'],2),nsmall=2),
                                    '',format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'pi_first_art.factor')]][2,'Effect'],2),nsmall=2),
                                    '',format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'overall_ade_prior_first_art.factor')]][2,'Effect'],2),nsmall=2)),
                       'Unadj CI'=c('',paste('(',format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'baseline_bmi')]][2,'Lower 0.95'],2),nsmall=2),', ',
                                          format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'baseline_bmi')]][2,'Upper 0.95'],2),nsmall=2),')',sep=''),
                                    '',
                                    paste('(',format(round(unadj_bmi_2[2,'Lower 0.95'],2),nsmall=2),', ',format(round(unadj_bmi_2[2,'Upper 0.95'],2),nsmall=2),')',sep=''),
                                    paste('(',format(round(unadj_bmi_3[2,'Lower 0.95'],2),nsmall=2),', ',format(round(unadj_bmi_3[2,'Upper 0.95'],2),nsmall=2),')',sep=''),
                                    '',paste('(',format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'age_at_first_art')]][2,'Lower 0.95'],2),nsmall=2),', ',
                                                 format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'age_at_first_art')]][2,'Upper 0.95'],2),nsmall=2),')',sep=''),
                                    '',paste('(',format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'dichot_race.factor')]][2,'Lower 0.95'],2),nsmall=2),', ',
                                          format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'dichot_race.factor')]][2,'Upper 0.95'],2),nsmall=2),')',sep=''),
                                    '',paste('(',format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'baseline_cd4_count')]][2,'Lower 0.95'],2),nsmall=2),', ',
                                          format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'baseline_cd4_count')]][2,'Upper 0.95'],2),nsmall=2),')',sep=''),
                                    '',paste('(',format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'year_of_first_art')]][2,'Lower 0.95'],2),nsmall=2),', ',
                                          format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'year_of_first_art')]][2,'Upper 0.95'],2),nsmall=2),')',sep=''),
                                    '',paste('(',format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'pi_first_art.factor')]][2,'Lower 0.95'],2),nsmall=2),', ',
                                          format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'pi_first_art.factor')]][2,'Upper 0.95'],2),nsmall=2),')',sep=''),
                                    '',paste('(',format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'overall_ade_prior_first_art.factor')]][2,'Lower 0.95'],2),nsmall=2),', ',
                                          format(round(summ_unadj_models[[which(names(summ_unadj_models) == 'overall_ade_prior_first_art.factor')]][2,'Upper 0.95'],2),nsmall=2),')',sep='')),
                       'Unadj p'=c(p_unadj[[1]],rep('',times=5),
                                   p_unadj[[2]],'',
                                   p_unadj[[3]],'',
                                   p_unadj[[4]],'',
                                   p_unadj[[5]],'',
                                   p_unadj[[6]],'',
                                   p_unadj[[7]]),
                       'HR'=c('',format(round(bmi_summ_1[order.rows[1],'Effect'],2),nsmall=2),
                                 format(1.00,nsmall=2),format(round(bmi_summ_2[order.rows[1],'Effect'],2),nsmall=2),
                                 format(round(bmi_summ_3[order.rows[1],'Effect'],2),nsmall=2),
                              '',format(round(bmi_summ_age[order.rows[2],'Effect'],2),nsmall=2),
                              '',format(round(bmi_summ_1[order.rows[3],'Effect'],2),nsmall=2),
                              '',format(round(bmi_summ_cd4[order.rows[4],'Effect'],2),nsmall=2),
                              '',format(round(bmi_summ_art_yr[order.rows[5],'Effect'],2),nsmall=2),
                              '',format(round(bmi_summ_1[order.rows[6],'Effect'],2),nsmall=2),
                              '',format(round(bmi_summ_1[order.rows[7],'Effect'],2),nsmall=2)),
                       'CI'=c('',
                              paste('(',format(round(bmi_summ_1[order.rows[1],'Lower 0.95'],2),nsmall=2),', ',format(round(bmi_summ_1[order.rows[1],'Upper 0.95'],2),nsmall=2),')',sep=''),'',
                              paste('(',format(round(bmi_summ_2[order.rows[1],'Lower 0.95'],2),nsmall=2),', ',format(round(bmi_summ_2[order.rows[1],'Upper 0.95'],2),nsmall=2),')',sep=''),
                              paste('(',format(round(bmi_summ_3[order.rows[1],'Lower 0.95'],2),nsmall=2),', ',format(round(bmi_summ_3[order.rows[1],'Upper 0.95'],2),nsmall=2),')',sep=''),'',
                              paste('(',format(round(bmi_summ_age[order.rows[2],'Lower 0.95'],2),nsmall=2),', ',format(round(bmi_summ_age[order.rows[2],'Upper 0.95'],2),nsmall=2),')',sep=''),'',
                              paste('(',format(round(bmi_summ_1[order.rows[3],'Lower 0.95'],2),nsmall=2),', ',format(round(bmi_summ_1[order.rows[3],'Upper 0.95'],2),nsmall=2),')',sep=''),'',
                              paste('(',format(round(bmi_summ_1[order.rows[4],'Lower 0.95'],2),nsmall=2),', ',format(round(bmi_summ_1[order.rows[4],'Upper 0.95'],2),nsmall=2),')',sep=''),'',
                              paste('(',format(round(bmi_summ_cd4[order.rows[5],'Lower 0.95'],2),nsmall=2),', ',format(round(bmi_summ_cd4[order.rows[5],'Upper 0.95'],2),nsmall=2),')',sep=''),'',
                              paste('(',format(round(bmi_summ_art_yr[order.rows[6],'Lower 0.95'],2),nsmall=2),', ',format(round(bmi_summ_art_yr[order.rows[6],'Upper 0.95'],2),nsmall=2),')',sep=''),'',
                              paste('(',format(round(bmi_summ_1[order.rows[7],'Lower 0.95'],2),nsmall=2),', ',format(round(bmi_summ_1[order.rows[7],'Upper 0.95'],2),nsmall=2),')',sep='')),
                       'P'=c(anova.p[anova.order[1]],rep('',times=5),
                             anova.p[anova.order[2]],'',
                             anova.p[anova.order[3]],'',
                             anova.p[anova.order[4]],'',
                             anova.p[anova.order[5]],'',
                             anova.p[anova.order[6]],'',
                             anova.p[anova.order[7]]))

      df <- as.matrix(df)
      colnames(df) <- c('Covariate','HR','95\\% CI','P','HR','95\\% CI','P')
   }
      return(list(no.evts=no.evts,
                  df=df,
                  followup_time.desc=followup_time.desc,
                  unadj_evts=unadj_evts,
                  cnts_by_bmi=cnts_by_bmi,
                  nmes_by_bmi=nmes_by_bmi,
                  cph.mod=cph.mod,
                  df_pts=df_pts,
                  followup_time.nonNA.bmi.desc=followup_time.nonNA.bmi.desc))
                           
}
